@@ -1,7 +1,8 @@
 /*
  *  conf.h
  *
- *  Copyright (c) 2002-2007 by Judd Vinet <jvinet@zeroflux.org>
+ *  Copyright (c) 2006-2009 Pacman Development Team <pacman-dev@archlinux.org>
+ *  Copyright (c) 2002-2006 by Judd Vinet <jvinet@zeroflux.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -50,6 +51,7 @@ typedef struct __config_t {
 	unsigned short op_q_search;
 	unsigned short op_q_changelog;
 	unsigned short op_q_upgrade;
+	unsigned short op_q_check;
 
 	unsigned short op_s_clean;
 	unsigned short op_s_downloadonly;
@@ -57,6 +59,7 @@ typedef struct __config_t {
 	unsigned short op_s_sync;
 	unsigned short op_s_search;
 	unsigned short op_s_upgrade;
+	unsigned short op_s_printuris;
 
 	unsigned short group;
 	pmtransflag_t flags;
@@ -68,7 +71,9 @@ typedef struct __config_t {
 	 * downloaded of the total download list */
 	unsigned short totaldownload;
 	unsigned short cleanmethod; /* select -Sc behavior */
+	alpm_list_t *holdpkg;
 	alpm_list_t *syncfirst;
+	char *xfercommand;
 } config_t;
 
 /* Operations */
